package com.ruoyi.set.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.set.mapper.SetImageUploadMapper;
import com.ruoyi.set.domain.SetImageUpload;
import com.ruoyi.set.service.ISetImageUploadService;

import javax.annotation.Resource;

/**
 * 七牛云设置Service业务层处理
 *
 * @author LCL
 * @date 2023-07-10
 */
@Service
public class SetImageUploadServiceImpl implements ISetImageUploadService
{
    @Resource
    private SetImageUploadMapper setImageUploadMapper;

    /**
     * 查询七牛云设置
     *
     * @param id 七牛云设置主键
     * @return 七牛云设置
     */
    @Override
    public SetImageUpload selectSetImageUploadById(Long id)
    {
        return setImageUploadMapper.selectSetImageUploadById(id);
    }

    /**
     * 查询七牛云设置列表
     *
     * @param setImageUpload 七牛云设置
     * @return 七牛云设置
     */
    @Override
    public List<SetImageUpload> selectSetImageUploadList(SetImageUpload setImageUpload)
    {
        return setImageUploadMapper.selectSetImageUploadList(setImageUpload);
    }

    /**
     * 新增七牛云设置
     *
     * @param setImageUpload 七牛云设置
     * @return 结果
     */
    @Override
    public int insertSetImageUpload(SetImageUpload setImageUpload)
    {
        return setImageUploadMapper.insertSetImageUpload(setImageUpload);
    }

    /**
     * 修改七牛云设置
     *
     * @param setImageUpload 七牛云设置
     * @return 结果
     */
    @Override
    public int updateSetImageUpload(SetImageUpload setImageUpload)
    {
        return setImageUploadMapper.updateSetImageUpload(setImageUpload);
    }

    /**
     * 批量删除七牛云设置
     *
     * @param ids 需要删除的七牛云设置主键
     * @return 结果
     */
    @Override
    public int deleteSetImageUploadByIds(Long[] ids)
    {
        return setImageUploadMapper.deleteSetImageUploadByIds(ids);
    }

    /**
     * 删除七牛云设置信息
     *
     * @param id 七牛云设置主键
     * @return 结果
     */
    @Override
    public int deleteSetImageUploadById(Long id)
    {
        return setImageUploadMapper.deleteSetImageUploadById(id);
    }
}
