package com.ruoyi.set.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.set.domain.SetImageUpload;
import com.ruoyi.set.service.ISetImageUploadService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 七牛云设置Controller
 *
 * @author LCL
 * @date 2023-07-10
 */
@RestController
@RequestMapping("/set/setImageUpload")
public class SetImageUploadController extends BaseController
{
    @Resource
    private ISetImageUploadService setImageUploadService;

    /**
     * 查询七牛云设置列表
     */
    @PreAuthorize("@ss.hasPermi('set:setImageUpload:list')")
    @GetMapping("/list")
    public TableDataInfo list(SetImageUpload setImageUpload)
    {
        startPage();
        List<SetImageUpload> list = setImageUploadService.selectSetImageUploadList(setImageUpload);
        return getDataTable(list);
    }

    /**
     * 导出七牛云设置列表
     */
    @PreAuthorize("@ss.hasPermi('set:setImageUpload:export')")
    @Log(title = "七牛云设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SetImageUpload setImageUpload)
    {
        List<SetImageUpload> list = setImageUploadService.selectSetImageUploadList(setImageUpload);
        ExcelUtil<SetImageUpload> util = new ExcelUtil<SetImageUpload>(SetImageUpload.class);
        util.exportExcel(response, list, "七牛云设置数据");
    }

    /**
     * 获取七牛云设置详细信息
     */
    @PreAuthorize("@ss.hasPermi('set:setImageUpload:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(setImageUploadService.selectSetImageUploadById(id));
    }

    /**
     * 新增七牛云设置
     */
    @PreAuthorize("@ss.hasPermi('set:setImageUpload:add')")
    @Log(title = "七牛云设置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SetImageUpload setImageUpload)
    {
        return toAjax(setImageUploadService.insertSetImageUpload(setImageUpload));
    }

    /**
     * 修改七牛云设置
     */
    @PreAuthorize("@ss.hasPermi('set:setImageUpload:edit')")
    @Log(title = "七牛云设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SetImageUpload setImageUpload)
    {
        return toAjax(setImageUploadService.updateSetImageUpload(setImageUpload));
    }

    /**
     * 删除七牛云设置
     */
    @PreAuthorize("@ss.hasPermi('set:setImageUpload:remove')")
    @Log(title = "七牛云设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(setImageUploadService.deleteSetImageUploadByIds(ids));
    }
}
